MetadataStore

Struct MetadataStore 

pub struct MetadataStore { /* private fields */ }

Implementations

Source

impl MetadataStore

pub fn fields(&self) -> impl Iterator<Item = &FieldDesc>

pub fn query_slk_field( &self, field_name: &str, object: &Object, ) -> Option<(&FieldDesc, Option<u32>)>

Queries an SLK field by it’s name and target object. The object is necessary because the same field name can resolve to different fields depending on the object.

pub fn query_profile_field( &self, field_name: &str, object: &Object, index: i8, ) -> Option<(&FieldDesc, Option<u32>)>

Queries a Profile field by it’s name and target object. The object is necessary because the same field name can resolve to different fields depending on the object.

pub fn query_object_field( &self, field_id: ObjectId, object: &Object, ) -> Option<&FieldDesc>

pub fn query_all_object_fields( &self, object: &Object, ) -> impl Iterator<Item = &FieldDesc>

Will return an iterator of all fields available for this object, irrespective of which fields exist on the object itself.

pub fn query_lua_field( &self, object: &Object, full_name: &str, ) -> Option<(&FieldDesc, Option<u32>)>

First tries to fetch a Profile/Func field in the format of <field_name>, e.g. Buttonpos1 resolving to abpx for units, and Buttonpos2 resolving to abpy, if that fails then will try to grab an slk field using the regular approach

pub fn field_by_id(&self, id: ObjectId) -> Option<&FieldDesc>