pub struct ObjectStoreStock { /* private fields */ }Implementations
Sourceimpl ObjectStoreStock
impl ObjectStoreStock
pub fn new(data: &ObjectStore) -> ObjectStoreStock
pub fn object(&self, id: ObjectId) -> Option<&Object>
Sourcepub fn object_prototype(&self, object: &Object) -> Option<&Object>
pub fn object_prototype(&self, object: &Object) -> Option<&Object>
Returns the ‘prototype’ for this object which is the parent if its a custom object, or the original if its a stock modified object
pub fn objects(&self) -> impl Iterator<Item = &Object>